Usage
jomo2com(Y.con=NULL, Y.cat=NULL, Y.numcat=NULL, Y2.con=NULL, Y2.cat=NULL,
Y2.numcat=NULL,X=NULL, X2=NULL, Z=NULL, clus, beta.start=NULL, l2.beta.start=NULL,
u.start=NULL, l1cov.start=NULL, l2cov.start=NULL, l1cov.prior=NULL,
l2cov.prior=NULL, nburn=1000, nbetween=1000, nimp=5, output=1, out.iter=10)
Arguments
Y.con
A data frame, or matrix, with level-1 continuous responses of the joint imputation model. Rows correspond to different observations, while columns are different variables.
Y.cat
A data frame, or matrix, with categorical (or binary) responses of the joint imputation model. Rows correspond to different observations, while columns are different variables. Missing values are coded as NA.
Y.numcat
A vector with the number of categories in each categorical (or binary) variable.
Y2.con
A data frame, or matrix, with level-2 continuous responses of the joint imputation model. Rows correspond to different observations, while columns are different variables.
Y2.cat
A data frame, or matrix, with level-2 categorical (or binary) responses of the joint imputation model. Rows correspond to different observations, while columns are different variables. Missing values are coded as NA.
Y2.numcat
A vector with the number of categories in each level-2 categorical (or binary) variable.
X
A data frame, or matrix, with covariates of the joint imputation model. Rows correspond to different observations, while columns are different variables. Missing values are not allowed in these variables. In case we want an intercept, a column of 1 is needed. The default is a column of 1.
X2
A data frame, or matrix, with level-2 covariates of the joint imputation model. Rows correspond to different observations, while columns are different variables. Missing values are not allowed in these variables. In case we want an intercept, a column of 1 is needed. The default is a column of 1.
Z
A data frame, or matrix, for covariates associated to random effects in the joint imputation model. Rows correspond to different observations, while columns are different variables. Missing values are not allowed in these variables. In case we want an intercept, a column of 1 is needed. The default is a column of 1.
clus
A data frame, or matrix, containing the cluster indicator for each observation.
beta.start
Starting value for beta, the vector(s) of level-1 fixed effects. Rows index different covariates and columns index different outcomes. For each n-category variable we have a fixed effect parameter for each of the n-1 latent normals. The default is a matrix of zeros.
l2.beta.start
Starting value for beta2, the vector(s) of level-2 fixed effects. Rows index different covariates and columns index different level-2 outcomes. For each n-category variable we have a fixed effect parameter for each of the n-1 latent normals. The default is a matrix of zeros.
u.start
A matrix where different rows are the starting values within each cluster for the random effects estimates u. The default is a matrix of zeros.
l1cov.start
Starting value for the covariance matrix. Dimension of this square matrix is equal to the number of outcomes (continuous plus latent normals) in the imputation model. The default is the identity matrix.
l2cov.start
Starting value for the level 2 covariance matrix. Dimension of this square matrix is equal to the number of outcomes (continuous plus latent normals) in the imputation model times the number of random effects plus the number of level-2 outcomes. The default is an identity matrix.
l1cov.prior
Scale matrix for the inverse-Wishart prior for the covariance matrix. The default is the identity matrix.
l2cov.prior
Scale matrix for the inverse-Wishart prior for the level 2 covariance matrix. The default is the identity matrix.
nburn
Number of burn in iterations. Default is 1000.
nbetween
Number of iterations between two successive imputations. Default is 1000.
nimp
Number of Imputations. Default is 5.
output
When set to any value different from 1 (default), no output is shown on screen at the end of the process.
out.iter
When set to K, every K iterations a message "Iteration number N*K completed" is printed on screen. Default is 10.