Learn R Programming

jomo (version 2.2-0)

sldata: A simulated single level dataset

Description

A simulated dataset to test single level functions, i.e. jomo1con, jomo1cat and jomo1mix.

Usage

data(sldata)

Arguments

Format

A data frame with 300 observations on the following 4 variables.

Details

These are not real data, they are simulated to illustrate the use of the main functions of the package.