Learn R Programming

jomo (version 2.2-0)

tldata: A simulated 2-level dataset

Description

A simulated dataset to test 2-level functions, i.e. jomo2com and jomo2hr.

Usage

data(tldata)

Arguments

Format

A data frame with 1000 observations on the following 6 variables.

Details

These are not real data, they are simulated to illustrate the use of the main functions of the package.