cldata:
A simulated clustered dataset
Description
A simulated dataset to test functions for imputation of clustered data, i.e. jomo1rancon, jomo1rancat, jomo1ranmix, jomo1ranconhr,jomo1rancathr and jomoran1mixhr.
Format
A data frame with 1000 observations on the following 6 variables.
Details
These are not real data, they are simulated to illustrate the use of the main functions of the package.